@@ -4,6 +4,7 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
+	"io"
 	"os"
 	"path/filepath"
 	"strings"
@@ -45,6 +46,14 @@ var (
 	completion string
 	// execCommand targets the output of executing the command.
 	execCommand bool
+
+	// forceScreen is display screen even when redirecting output.
+	forceScreen bool
+
+	// alignF is align column.
+	alignF bool
+	// rawF is raw output of escape sequences.
+	rawF bool
 )
 
 var (
@@ -52,6 +61,8 @@ var (
 	ErrCompletion = errors.New("requires one of the arguments bash/zsh/fish/powershell")
 	// ErrNoArgument indicating that there are no arguments to execute.
 	ErrNoArgument = errors.New("no arguments to execute")
+	// ErrMissingFile indicates that the file is missing.
+	ErrMissingFile = errors.New("missing file")
 )
 
 // rootCmd represents the base command when called without any subcommands.
@@ -99,12 +110,23 @@ It supports various compressed files(gzip, bzip2, zstd, lz4, and xz).
 			config.General.SectionHeader = true
 		}
 
+		// Set a converter by specifying flag.
+		if alignF {
+			config.General.Converter = "align"
+		} else if rawF {
+			config.General.Converter = "raw"
+		}
+
 		// Set a global variable to convert to a style before opening the file.
 		oviewer.OverStrikeStyle = oviewer.ToTcellStyle(config.StyleOverStrike)
 		oviewer.OverLineStyle = oviewer.ToTcellStyle(config.StyleOverLine)
 		oviewer.MemoryLimit = config.MemoryLimit
 		oviewer.MemoryLimitFile = config.MemoryLimitFile
 		SetRedirect()
+		// Do not display the screen if redirected (unless forceScreen is specified).
+		if oviewer.STDOUTPIPE != nil && !forceScreen {
+			return copyOutput(args)
+		}
 
 		if execCommand {
 			return ExecCommand(args)
@@ -177,7 +199,7 @@ func RunOviewer(args []string) error {
 	if ov.QuitSmall && (filter != "" || nonMatchFilter != "") {
 		ov.QuitSmallFilter = true
 	}
-
+	// Run oviewer.
 	if err := ov.Run(); err != nil {
 		return err
 	}
@@ -323,6 +345,35 @@ func flagUsage(f *pflag.FlagSet) string {
 	return buf.String()
 }
 
+func openFile(fileName string) (*os.File, error) {
+	if fileName == "" {
+		fd := os.Stdin.Fd()
+		if term.IsTerminal(int(fd)) {
+			return nil, ErrMissingFile
+		}
+		return os.Stdin, nil
+	}
+	return os.Open(fileName)
+}
+
+// copyOutput just outputs the input (standard input if there is no first file).
+func copyOutput(args []string) error {
+	files := argsToFiles(args)
+	fileName := ""
+	if len(files) > 0 {
+		fileName = files[0]
+	}
+	file, err := openFile(fileName)
+	if err != nil {
+		return err
+	}
+	defer file.Close()
+
+	r := io.Reader(file)
+	_, err = io.Copy(oviewer.STDOUTPIPE, r)
+	return err
+}
+
 // UsageFunc returns a function that returns the usage.
 // This is for overwriting cobra usage.
 func UsageFunc() (cmd func(*cobra.Command) error) {
@@ -348,6 +399,8 @@ func init() {
 	rootCmd.PersistentFlags().BoolVarP(&helpKey, "help-key", "", false, "display key bind information")
 	rootCmd.PersistentFlags().BoolVarP(&execCommand, "exec", "e", false, "command execution result instead of file")
 
+	rootCmd.PersistentFlags().BoolVarP(&forceScreen, "force-screen", "", false, "display screen even when redirecting output")
+
 	rootCmd.PersistentFlags().StringVarP(&completion, "completion", "", "", "generate completion script [bash|zsh|fish|powershell]")
 	_ = rootCmd.RegisterFlagCompletionFunc("completion", func(_ *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
 		return []string{"bash", "zsh", "fish", "powershell"}, cobra.ShellCompDirectiveNoFileComp
@@ -358,7 +411,16 @@ func init() {
 	rootCmd.PersistentFlags().StringVarP(&nonMatchFilter, "non-match-filter", "", "", "filter non match search pattern")
 	rootCmd.PersistentFlags().BoolVarP(&oviewer.SkipExtract, "skip-extract", "", false, "skip extracting compressed files")
 
+	rootCmd.PersistentFlags().BoolVarP(&alignF, "align", "l", false, "align the output columns for better readability")
+	rootCmd.PersistentFlags().BoolVarP(&rawF, "raw", "r", false, "raw escape sequences without processing")
+
 	// Config.General
+	rootCmd.PersistentFlags().StringP("converter", "", "es", "converter [es|raw|align]")
+	_ = viper.BindPFlag("general.Converter", rootCmd.PersistentFlags().Lookup("converter"))
+	_ = rootCmd.RegisterFlagCompletionFunc("converter", func(_ *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
+		return []string{"es\tEscape Sequence", "raw\tRaw output of escape sequences", "align\tAlign Column Widths"}, cobra.ShellCompDirectiveNoFileComp
+	})
+
 	rootCmd.PersistentFlags().IntP("tab-width", "x", 8, "tab stop width")
 	_ = viper.BindPFlag("general.TabWidth", rootCmd.PersistentFlags().Lookup("tab-width"))
 	_ = rootCmd.RegisterFlagCompletionFunc("tab-width", func(_ *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
